@@ -31,7 +31,7 @@ TEST(stream, send) {
 
     swListenPort *port = serv.add_port(SW_SOCK_TCP, TEST_HOST, TEST_PORT);
     if (!port) {
-        swWarn("listen failed, [error=%d]", swoole_get_last_error());
+        swoole_warning("listen failed, [error=%d]", swoole_get_last_error());
         exit(2);
     }
 
@@ -47,7 +47,7 @@ TEST(stream, send) {
     ASSERT_EQ(serv.create(), SW_OK);
 
     std::thread t1([&]() {
-        swSignal_none();
+        swoole_signal_block_all();
 
         lock.lock();
 
